==> dasu_1.0.jar: edu/northwestern/dasu/measurement/DasuProbeModule.java <==
/**
 * Dasu Project
 *
 * File:         DasuProbeModule.java
 * RCS:          $Id: DasuProbeModule.java,v 1.5 2010/06/02 02:14:04 mas939 Exp $
 * Description:  OptimalEdge class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 15, 2008 at 07:38:30 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;


import java.util.List;

import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.util.PluginInterface;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 *         The DasuProbeModule abstract class servers as 
 *         tempalte for all the ProbeModules
 */

public abstract class DasuProbeModule extends Thread {	
		
	protected Boolean active;
	protected boolean pause = false;
	protected PluginInterface pi;
	protected final boolean DEBUG = false;
	protected int sleepInterval = 30; //seconds 
	protected int pauseInterval = 10; //seconds
	
	protected DasuProbeModule(String name) {
		super(name);
	}
	
	public void setActive(boolean active) {
		this.active = active;
	}
	
	public boolean isActive() {
		return active;
	}
	
	public void setPause(boolean paused) {
		this.pause = paused;
	}
	
	public boolean isPause() {
		return pause;
	}

	@Override
	public synchronized void start() {
		super.start();
	}	

	public void probeAll(List<String> list, Integer taskId) {

	}
	
	public void probeWithPriority(String ip, Integer taskId) {
				
	}

	public void probe(String ip, Integer taskId) {

	}
	
	
	@Override
	public void run() {

	}
		
	protected Object probeIp(final String ipAddress, final Integer taskId) {
		return ipAddress;
	}
	 

	protected String getIp() {
		return MainGeneric.getPublicIpAddress();
	}
	
	public static boolean isValidIp(final String ip) {
        return ip.matches("^[\\d]{1,3}\\.[\\d]{1,3}\\.[\\d]{1,3}\\.[\\d]{1,3}$");
    }
	
	public void stopModule() {
		
	}
	
	
}

==> dasu_2.02.jar: edu/northwestern/dasu/measurement/DasuProbeModule.java <==
/**
 * Dasu Project
 *
 * File:         DasuProbeModule.java
 * RCS:          $Id: DasuProbeModule.java,v 1.7 2010/11/01 15:37:00 mas939 Exp $
 * Description:  OptimalEdge class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 15, 2008 at 07:38:30 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2008, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.measurement;


import java.util.List;

import edu.northwestern.dasu.MainGeneric;
import edu.northwestern.dasu.util.PluginInterface;

/**
 * @author Mario Sanchez &lt;msanchez@u.northwestern.edu&gt;
 * 
 *         The DasuProbeModule abstract class servers as 
 *         template for all the ProbeModules
 */

public abstract class DasuProbeModule extends Thread {	
		
	protected Boolean active = false;
	protected boolean pause = false;
	protected PluginInterface pi;
	protected final boolean DEBUG = false;
	protected int sleepInterval = 30; //seconds 
	protected int pauseInterval = 10; //seconds
	
	protected DasuProbeModule(String name) {
		super(name);
	}
	
	public void setActive(boolean active) {
		this.active = active;
	}
	
	public boolean isActive() {
		return active;
	}
	
	public void setPause(boolean paused) {
		this.pause = paused;
	}
	
	public boolean isPause() {
		return pause;
	}

	@Override
	public synchronized void start() {
		super.start();
	}	

	public void probeAll(List<String> list, Integer taskId) {

	}
	
	public void probeWithPriority(String ip, Integer taskId) {
				
	}

	public void probe(String ip, Integer taskId) {

	}
	
	
	@Override
	public void run() {

	}
		
	protected Object probeIp(final String ipAddress, final Integer taskId) {
		return ipAddress;
	}
	 

	protected String getIp() {
		return MainGeneric.getPublicIpAddress();
	}
	
	public static boolean isValidIp(final String ip) {
        return ip.matches("^[\\d]{1,3}\\.[\\d]{1,3}\\.[\\d]{1,3}\\.[\\d]{1,3}$");
    }
	
	public void stopModule() {
		
	}
	
	
}
